CaptureLogger is copyright 2025 Austin Ziegler and is licensed under the
Apache License, version 2.0. It is adapted from
ExUnit.CaptureLog and ExUnit.CaptureServer modules in Elixir.
- SPDX License: Apache-2.0
Developer Certificate of Origin
All contributors must certify they are willing and able to provide their contributions under the terms of this project's licences with the certification of the Developer Certificate of Origin (Version 1.1).
Such certification is provided by ensuring that a Signed-off-by
commit trailer is present on every commit:
Signed-off-by: FirstName LastName <email@example.org>The Signed-off-by trailer can be automatically added by git with the -s or
--signoff option on git commit:
git commit --signoff